[SCM] kdeconnect packaging branch, master, updated. debian/0.9g-1-1183-g9d69498

Maximiliano Curia maxy at moszumanska.debian.org
Fri Oct 14 14:29:51 UTC 2016


Gitweb-URL: http://git.debian.org/?p=pkg-kde/kde-extras/kdeconnect.git;a=commitdiff;h=c4d7c2f

The following commit has been merged in the master branch:
commit c4d7c2f39bee8f72df8db236183ff8ae995fb4b3
Author: Albert Vaca <albertvaka at gmail.com>
Date:   Fri Jun 17 01:59:53 2016 +0200

    Improved comments
---
 core/backends/lan/lanlinkprovider.cpp | 7 ++++---
 1 file changed, 4 insertions(+), 3 deletions(-)

diff --git a/core/backends/lan/lanlinkprovider.cpp b/core/backends/lan/lanlinkprovider.cpp
index 6dd91f3..b819f87 100644
--- a/core/backends/lan/lanlinkprovider.cpp
+++ b/core/backends/lan/lanlinkprovider.cpp
@@ -199,6 +199,7 @@ void LanLinkProvider::connectError()
     delete socket;
 }
 
+//We received a UDP package and answered by connecting to them by TCP. This gets called on a succesful connection.
 void LanLinkProvider::connected()
 {
     qCDebug(KDECONNECT_CORE) << "Socket connected";
@@ -225,7 +226,7 @@ void LanLinkProvider::connected()
 
     if (success) {
 
-        qCDebug(KDECONNECT_CORE) << "Handshaking done (i'm the existing device)";
+        qCDebug(KDECONNECT_CORE) << "TCP connection done (i'm the existing device)";
 
         // if ssl supported
         if (receivedPackage->get<int>("protocolVersion") >= MIN_VERSION_WITH_SSL_SUPPORT) {
@@ -326,7 +327,7 @@ void LanLinkProvider::sslErrorsLogButIgnore(const QList<QSslError>& errors)
     }
 }
 
 //I'm the new device and this is the answer to my UDP identity package (no data received yet)
 void LanLinkProvider::newConnection()
 {
     //qCDebug(KDECONNECT_CORE) << "LanLinkProvider newConnection";
@@ -409,8 +410,8 @@ void LanLinkProvider::dataReceived()
 
 void LanLinkProvider::deviceLinkDestroyed(QObject* destroyedDeviceLink)
 {
-    //qCDebug(KDECONNECT_CORE) << "deviceLinkDestroyed";
     const QString id = destroyedDeviceLink->property("deviceId").toString();
+    //qCDebug(KDECONNECT_CORE) << "deviceLinkDestroyed" << id;
     Q_ASSERT(mLinks.key(static_cast<LanDeviceLink*>(destroyedDeviceLink)) == id);
     QMap< QString, LanDeviceLink* >::iterator linkIterator = mLinks.find(id);
     if (linkIterator != mLinks.end()) {
@@ -326,7 +327,7 @@ void LanLinkProvider::sslErrorsLogButIgnore(const QList<QSslError>& errors)
 }
 
-//I'm the new device and this is the answer to my UDP identity package (no data received yet)
+//I'm the new device and this is the answer to my UDP identity package (no data received yet). They are connecting to us through TCP, and they should send an identity.
 void LanLinkProvider::newConnection()
 {

-- 
kdeconnect packaging



More information about the pkg-kde-commits mailing list